@@ -15,8 +15,10 @@
 #  limitations under the License.
 
 import re
+from calculate.lib.cl_template import TemplateFormat
 
-class objShare(object):
+
+class objShare(TemplateFormat):
     """Общий клас для объектов, наследуем
     """
     docObj = None
